@@ -10,6 +10,8 @@
 #'   \item{Autosize: }{Adapts to viewport (graph) size}
 #' }
 #'
+#' See \code{vignette("forestplot")} for details.
+#'
 #' @section Multiple bands:
 #'
 #' Using multiple bands, i.e. multiple lines, per variable can be interesting when
@@ -18,6 +20,25 @@
 #' have two bands on top of eachother. Another useful implementation is to show
 #' crude and adjusted estimates as separate bands.
 #'
+#' @section Horizontal lines:
+#'
+#' The argument \code{hrzl_lines} can be either \code{TRUE} or a \code{list} with \code{\link[grid]{gpar}}
+#' elements:
+#'
+#' \itemize{
+#'  \item{\code{TRUE}}{A line will be added based upon the \code{is.summary} rows. If the first line is a summary it}
+#'  \item{\code{\link[grid]{gpar}}}{The same as above but the lines will be formatted according to the
+#'                                  \code{\link[grid]{gpar}} element}
+#'  \item{\code{list}}{The list must either be numbered, i.e. \code{list("2" = gpar(lty=1))}, or have the same length
+#'                     as the \code{NROW(mean) + 1}. If the list is numbered the numbers should not exceed the \code{NROW(mean) + 1}.
+#'                     The no. \emph{1 row designates the top}, i.e. the line above the first row, all other correspond  to
+#'                     \emph{the row below}. Each element in the list needs to be \code{TRUE}, \code{NULL}, or
+#'                     \code{\link[grid]{gpar}} element. The \code{TRUE} defaults to a standard line, the \code{NULL}
+#'                     skips a line, while \code{\link[grid]{gpar}} corresponds to the fully customized line. Apart from
+#'                     allowing standard \code{\link[grid]{gpar}} line descriptions, \code{lty}, \code{lwd}, \code{col}, and more
+#'                     you can also specify \code{gpar(columns = c(1:3, 5))} if you for instance want the line to skip a column.}
+#' }
+#'
 #' @section Known issues:
 #'
 #' The x-axis does not entirely respect the margin. Autosizing boxes is not
@@ -48,8 +69,14 @@
 #' @param upper The upper bound of the confidence interval for the forestplot, needs
 #'   to be the same format as the mean, i.e. matrix/vector of equal columns & length
 #' @param align Vector giving alignment (l,r,c) for the table columns
-#' @param is.summary A vector indicating by TRUE/FALSE if the value is a summary
-#'   value which means that it will have a different font-style
+#' @param is.summary A vector indicating by \code{TRUE}/\code{FALSE} if
+#'   the value is a summary value which means that it will have a different
+#'   font-style
+#' @param graph.pos The position of the graph element within the table of text. The
+#'   position can be \code{1-(ncol(labeltext) + 1)}. You can also choose set the positin
+#'   to \code{"left"} or \code{"right"}.
+#' @param hrzl_lines Add horizontal lines to graph. Can either be \code{TRUE} or a \code{list}
+#'   of \code{\link[grid]{gpar}}. See line section below for details.
 #' @param clip Lower and upper limits for clipping confidence intervals to arrows
 #' @param xlab x-axis label
 #' @param zero x-axis coordinate for zero line. If you provide a vector of length 2 it
@@ -118,6 +145,8 @@ forestplot <- function (labeltext,
                         mean, lower, upper,
                         align,
                         is.summary           = FALSE,
+                        graph.pos            = "right",
+                        hrzl_lines,
                         clip                 = c(-Inf, Inf),
                         xlab                 = "",
                         zero                 = ifelse(xlog, 1, 0),
@@ -138,8 +167,8 @@ forestplot <- function (labeltext,
                         legend,
                         legend_args          = fpLegend(),
                         new_page             = FALSE,
-                        fn.ci_norm      = fpDrawNormalCI,
-                        fn.ci_sum     = fpDrawSummaryCI,
+                        fn.ci_norm           = fpDrawNormalCI,
+                        fn.ci_sum            = fpDrawSummaryCI,
                         fn.legend,
                         ...)
 {
@@ -212,7 +241,6 @@ forestplot <- function (labeltext,
   if (is.null(labeltext))
     stop("You must provide labeltext either in the direct form as an argument",
          " or as rownames for the mean argument.")
-
   # Assume that lower and upper are contained within
   # the mean variable
   if (missing(lower) &&
@@ -385,15 +413,45 @@ forestplot <- function (labeltext,
     label_type = "matrix"
   }
 
+
+  if (is.character(graph.pos)){
+    graph.pos <-
+      switch(graph.pos,
+             right = nc + 1,
+             last = nc + 1,
+             left = 1,
+             first = 1,
+             stop("The graph.pos argument has an invalid text argument.",
+                  " The only values accepted are 'left'/'right' or 'first'/'last'.",
+                  " You have provided the value '", graph.pos, "'"))
+  }else if(is.numeric(graph.pos)){
+    if (!graph.pos %in% 1:(NCOL(labeltext) + 1))
+      stop("The graph position must be between 1 and ", (NCOL(labeltext) + 1), ".",
+           " You have provided the value '", graph.pos, "'.")
+  }else{
+    stop("The graph pos must either be a string consisting of 'left'/'right' (alt. 'first'/'last')",
+         ", or an integer value between 1 and ", (NCOL(labeltext) + 1))
+  }
+
   # Prepare the summary and align variables
   if (missing(align)){
-    align <- c("l", rep("r", nc - 1))
+    if (graph.pos == 1)
+      align <- rep("l", nc)
+    else if (graph.pos == nc + 1)
+      align <- c("l", rep("r", nc - 1))
+    else
+      align <- c("l",
+                 rep("c", nc - 1))
   } else {
-    align <- rep(align, length = nc)
+    align <- rep(align, length.out = nc)
   }
 
   is.summary <- rep(is.summary, length = nr)
 
+  hrzl_lines <- prFpGetLines(hrzl_lines = hrzl_lines,
+                             is.summary = is.summary,
+                             total_columns = nc + 1,
+                             col = col)
 
   labels <- prFpGetLabels(label_type = label_type,
                           labeltext = labeltext, align = align,
@@ -414,14 +472,14 @@ forestplot <- function (labeltext,
 
   # There is always at least one column so grab the widest one
   # and have that as the base for the column widths
-  colwidths <- unit.c(prFpFindWidestGrob(labels[[1]]), colgap)
+  colwidths <- unit.c(prFpFindWidestGrob(labels[[1]]))
 
   # If multiple row label columns, add the other column widths
   if (nc > 1) {
     for (i in 2:nc){
       colwidths <- unit.c(colwidths,
-                          prFpFindWidestGrob(labels[[i]]),
-                          colgap)
+                          colgap,
+                          prFpFindWidestGrob(labels[[i]]))
     }
   }
 
@@ -440,8 +498,8 @@ forestplot <- function (labeltext,
                                                            zero = zero,
                                                            xticks = xticks,
                                                            xlog = xlog),
-                                        nc = nc,
-                                        mean = org_mean)
+                                        mean = org_mean,
+                                        graph.pos = graph.pos)
   clip <- axisList$clip
 
   ###################
@@ -566,25 +624,31 @@ forestplot <- function (labeltext,
   # Normalize the widths to cover the whole #
   # width of the graph space.               #
   ###########################################
-  if (is.unit(graphwidth)){
-    # Add the base grapwh width to the total column width
-    # default is 2 inches
-    colwidths <- unit.c(colwidths, graphwidth)
-
-    npc_colwidths <- convertUnit(colwidths, "npc", valueOnly=TRUE)
-    colwidths <- unit(npc_colwidths/sum(npc_colwidths), "npc")
-  }else if(graphwidth=="auto"){
+  if(graphwidth=="auto"){
     # If graph width is not provided as a unit the autosize it to the
     # rest of the space available
-    npc_colwidths <- convertUnit(colwidths, "npc", valueOnly=TRUE)
+    npc_colwidths <- convertUnit(unit.c(colwidths, colgap), "npc", valueOnly=TRUE)
     graphwidth <- unit(1 - sum(npc_colwidths), "npc")
-    colwidths <- unit.c(colwidths, graphwidth)
-  }else{
-    stop("You have to provide graph width either as a unit() object or as auto.",
+  }else if(!is.unit(graphwidth)){
+    stop("You have to provide graph width either as a unit() object or as 'auto'.",
       " Auto sizes the graph to maximally use the available space.",
       " If you want to have exact mm width then use graphwidth = unit(34, 'mm').")
   }
 
+  # Add the base grapwh width to the total column width
+  # default is 2 inches
+  if (graph.pos == 1){
+    colwidths <- unit.c(graphwidth, colgap, colwidths)
+  }else if (graph.pos == nc + 1){
+    colwidths <- unit.c(colwidths, colgap, graphwidth)
+  }else{
+    spl_position <- ((graph.pos-1)*2 - 1)
+    colwidths <- unit.c(colwidths[1:spl_position],
+                        colgap,
+                        graphwidth,
+                        colwidths[(spl_position + 1):length(colwidths)])
+  }
+
   # Add space for the axis and the label
   axis_height <- unit(0, "npc")
   if (is.grob(axisList$axisGrob))
@@ -639,18 +703,19 @@ forestplot <- function (labeltext,
     info[is.summary] <- 1/NCOL(org_mean)
   }
 
-  prFpPrintLabels(labels=labels,
-                  nc=nc,
-                  nr=nr)
+  prFpPrintLabels(labels = labels,
+                  nc = nc,
+                  nr = nr,
+                  graph.pos = graph.pos)
 
   prFpPrintXaxis(axisList=axisList,
                  col=col, lwd.zero=lwd.zero)
 
+  prFpDrawLines(hrzl_lines = hrzl_lines, nr = nr, colwidths = colwidths,
+                graph.pos = graph.pos)
+
   # Output the different confidence intervals
   for (i in 1:nr) {
-    if (is.na(mean[i]))
-      next
-
     if (is.matrix(org_mean)){
       low_values <- org_lower[i,]
       mean_values <- org_mean[i,]
@@ -669,9 +734,9 @@ forestplot <- function (labeltext,
     clr.summary <- rep(col$summary, length.out=length(low_values))
 
     line_vp <- viewport(layout.pos.row = i,
-                        layout.pos.col = length(colwidths),
+                        layout.pos.col = graph.pos * 2 - 1,
                         xscale = axisList$x_range,
-                        name = sprintf("Line_%d_%d", i, 2 * nc + 1))
+                        name = sprintf("Line_%d_%d", i, graph.pos*2-1))
     pushViewport(line_vp)
 
     # Draw multiple confidence intervals
@@ -693,6 +758,9 @@ forestplot <- function (labeltext,
         # the one on top should always be
         # above the one below
         current_y.offset <- y.offset_base + (length(low_values)-j)*y.offset_increase
+        if (is.na(mean_values[j]))
+          next;
+
         if (is.summary[i]){
           call_list <-
             list(fn.ci_sum[[i]][[j]],
@@ -760,8 +828,8 @@ forestplot <- function (labeltext,
       }
 
       # Do the actual drawing of the object
-      eval(as.call(call_list))
-
+      if (!is.na(mean_values))
+        eval(as.call(call_list))
     }
 
     upViewport()
@@ -771,7 +839,7 @@ forestplot <- function (labeltext,
   if (!missing(legend) &&
         is.list(legend_args$pos)){
     plot_vp <- viewport(layout.pos.row = 1:nr,
-      layout.pos.col = 2 * nc + 1,
+      layout.pos.col = 2 * graph.pos - 1,
       name = "main_plot_area")
     pushViewport(plot_vp)
 
